@@ -33,6 +33,23 @@ class TestRaises(object):
         except pytest.raises.Exception:
             pass
 
+    def test_raises_repr_inflight(self):
+        """Ensure repr() on an exception info inside a pytest.raises with block works (#4386)"""
+
+        class E(Exception):
+            pass
+
+        with pytest.raises(E) as excinfo:
+            # this test prints the inflight uninitialized object
+            # using repr and str as well as pprint to demonstrate
+            # it works
+            print(str(excinfo))
+            print(repr(excinfo))
+            import pprint
+
+            pprint.pprint(excinfo)
+            raise E()
+
     def test_raises_as_contextmanager(self, testdir):
         testdir.makepyfile(
             """
@@ -43,7 +60,7 @@ class TestRaises(object):
                 with pytest.raises(ZeroDivisionError) as excinfo:
                     assert isinstance(excinfo, _pytest._code.ExceptionInfo)
                     1/0
-                print (excinfo)
+                print(excinfo)
                 assert excinfo.type == ZeroDivisionError
                 assert isinstance(excinfo.value, ZeroDivisionError)
 
